@@ -7,15 +7,15 @@ from cropioai.project.utils import memoize
 """Decorators for defining cropio components and their behaviors."""
 
 
-def before_takeoff(func):
-    """Marks a method to execute before cropio takeoff."""
-    func.is_before_takeoff = True
+def before_ignite(func):
+    """Marks a method to execute before cropio ignite."""
+    func.is_before_ignite = True
     return func
 
 
-def after_takeoff(func):
-    """Marks a method to execute after cropio takeoff."""
-    func.is_after_takeoff = True
+def after_ignite(func):
+    """Marks a method to execute after cropio ignite."""
+    func.is_after_ignite = True
     return func
 
 
@@ -117,10 +117,10 @@ def cropio(func) -> Callable[..., Cropio]:
 
             return wrapper
 
-        for _, callback in self._before_takeoff.items():
-            cropio.before_takeoff_callbacks.append(callback_wrapper(callback, self))
-        for _, callback in self._after_takeoff.items():
-            cropio.after_takeoff_callbacks.append(callback_wrapper(callback, self))
+        for _, callback in self._before_ignite.items():
+            cropio.before_ignite_callbacks.append(callback_wrapper(callback, self))
+        for _, callback in self._after_ignite.items():
+            cropio.after_ignite_callbacks.append(callback_wrapper(callback, self))
 
         return cropio
 
